@@ -36,8 +36,14 @@ type Parser = Parsec Void Text
 parseOnly :: Parsec Void Text a -> Text -> Either String a
 parseOnly p s = first errorBundlePretty $ parse p "input.fasta" s
 
+-- Using 'hspace1' instead of just 'space1' because our 'fastaLine' parser
+-- expects each line to end with line-ending or end of file. But if 'sc' consumes end-of-line,
+-- 'lexeme' in 'unknownP' also will and 'fastaLine' will not know that line has ended and will
+-- expect more symbols.
+--
+-- 'hspace1' consumes only "horizontal" space, leaving line-ending for 'fastaLine'.
 sc :: Parser ()
-sc = L.space space1 empty empty
+sc = L.space hspace1 empty empty
 
 lexeme :: Parser a -> Parser a
 lexeme = L.lexeme sc
@@ -121,6 +127,7 @@ modificationP
   , string "[3CholTEG]" $> Mod_3CholTEG
   , string "[5C10]" $> Mod_5C10
   , string "[5Alk]" $> Mod_5Alk
+  , string "[5ROX]" $> Mod_5ROX
   , string "[GC]" $> Mod_GC
   , string "[GT]" $> Mod_GT
   , string "[AT]" $> Mod_AT
